pub enum EnvStructError {
ParseEnvError {
var_name: String,
var_value: String,
source: BoxError,
},
ParseDefaultError {
var_name: String,
var_value: String,
source: BoxError,
},
MissingEnvVar(String),
InvalidKeyFormat(String),
InvalidVarFormat(String),
}Expand description
Represents errors that can occur while processing environment variables.
Variants
ParseEnvError
Error that occurs when an environment variable cannot be parsed.
var_name is the name of the environment variable.
var_value is the value of the environment variable.
source is the underlying error that caused this error.
ParseDefaultError
Error that occurs when a default value cannot be parsed.
var_name is the name of the environment variable.
var_value is the default value of the environment variable.
source is the underlying error that caused this error.
MissingEnvVar(String)
Error that occurs when an expected environment variable is missing.
The string is the name of the missing environment variable.
InvalidKeyFormat(String)
Error that occurs when an environment variable key has an invalid format.
The string is the invalid key.
InvalidVarFormat(String)
Error that occurs when an environment variable value has an invalid format.
The string is the invalid value.